/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource;

import org.diirt.datasource.ConfigurableDataSourceProvider;

/**
 * <p>
 * Data source provider for the {@link JackieDataSource}. This class is abstract
 * because there are two different variants for the data source provider:
 * </p>
 * 
 * <p>
 * The {@code CaDataSourceProvider} uses the name <em>ca</em>, while the
 * {@code JackieDataSourceProvider} uses the name <em>jackie</em>. Apart from
 * this, they are identical. These two differents providers exist, because the
 * <em>ca</em> name collides with the name of the JCA-based data-source provider
 * for the Channel Access protocol. This means that the
 * {@code CaDataSourceProvider} should never be on the class-path when the
 * {@code JCADataSourceProvider} is also present. In this case, the
 * {@code JackieDataSourceProvider} can be used so that both data-source types
 * can be used at the same time.
 * </p>
 * 
 * <p>
 * When the {@code JCADataSourceProvider} is not on the class-path, the
 * {@code CaDataSourceProvider} can be used so that the name of the data-source
 * (and thus the prefix for the process variable names) is the same as if the
 * {@code JCADataSourceProvider} was used. This is particularly useful when
 * migrating from JCA to EPICS Jackie.
 * </p>
 * 
 * @author Sebastian Marsching
 */
public abstract class AbstractJackieDataSourceProvider extends
        ConfigurableDataSourceProvider<JackieDataSource, JackieDataSourceConfiguration> {

    /**
     * Creates the data source provider that provides {@link JackieDataSource}s.
     */
    protected AbstractJackieDataSourceProvider() {
        super(JackieDataSourceConfiguration.class);
    }

}
